@@ -8,8 +8,8 @@
 ## Apr 20, 1999 Change for draft-hiroshi-dom-hash-01.txt
 ##
 
-require 'xmltreebuilder'
-require 'xmldigest'
+require 'xml/dom/builder'
+require 'xml/dom/digest'
 
 p = XML::DOM::Builder.new(0, nil, ":") ## nssep must be ':'
 if p.respond_to?(:setParamEntityParsing)
