@@ -1,6 +1,6 @@
 #! /usr/local/bin/ruby
 
-require 'xmlparser'
+require 'xml/parser'
 
 p = XML::Parser.new(nil, " ")
 p.setReturnNSTriplet(true);
@@ -15,5 +15,5 @@ def p.startElement(name, attrs) end
 def p.endElement(name) end
 
 p.parse($<.read) do |t, n, d|
-  p [t, n, d]
+  p([t, n, d])
 end
