@@ -1,6 +1,6 @@
 #! /usr/local/bin/ruby
 
-require 'xmlparser'
+require 'xml/parser'
 
 class ExtDTDParser < XML::Parser
   def startElement(name, attr)
@@ -23,12 +23,12 @@ class ExtDTDParser < XML::Parser
   end
 end
 
-p = ExtDTDParser.new
+p = ExtDTDParser.new(nil, '!')
 if p.respond_to?(:setParamEntityParsing)
   p.setParamEntityParsing(XML::Parser::PARAM_ENTITY_PARSING_UNLESS_STANDALONE)
 end
 begin
   p.parse($<.read)
-rescue XML::ParserError
+rescue XML::Parser::Error
   print "#{$!} in l.#{p.line}\n"
 end
