@@ -77,6 +77,6 @@ else
 end
 begin
   p.parse($<.read)
-rescue XMLParserError
-  p [$!, p.line]
+rescue XML::Parser::Error
+  p([$!, p.line])
 end
