@@ -54,28 +54,28 @@ end
 begin
   p.parse($<.read) do |event, name, data|
     case event
-    when XMLParser::EXTERNAL_PARSED_ENTITY_DECL
-      p ["externalParsedEntityDecl", name, data]
+    when XML::Parser::EXTERNAL_PARSED_ENTITY_DECL
+      p(["externalParsedEntityDecl", name, data])
 
-    when XMLParser::INTERNAL_PARSED_ENTITY_DECL
-      p ["internalParsedEntityDecl", name, data]
+    when XML::Parser::INTERNAL_PARSED_ENTITY_DECL
+      p(["internalParsedEntityDecl", name, data])
 
 
-    when XMLParser::START_ELEM
+    when XML::Parser::START_ELEM
       print "<" + name
       data.each do |n, v|
         print " " + n + "='" + escapeAttrVal(v) + "'"
       end
       print  ">"
 
-    when XMLParser::END_ELEM
+    when XML::Parser::END_ELEM
       print "</" + name + ">"
 
-    when XMLParser::CDATA
+    when XML::Parser::CDATA
       print escapeText(data)
 
     end
   end
-rescue XMLParserError
-  p [$!, p.line]
+rescue XML::Parser::Error
+  p([$!, p.line])
 end
