@@ -1,4 +1,4 @@
-require 'xmlparser'
+require 'xml/parser'
 
 module XML
   class ExtParser < Parser
@@ -9,13 +9,13 @@ module XML
     end
 
     def parse(*args)
-      setParamEntityParsing(XMLParser::PARAM_ENTITY_PARSING_UNLESS_STANDALONE)
+      setParamEntityParsing(XML::Parser::PARAM_ENTITY_PARSING_UNLESS_STANDALONE)
 
       if iterator?
         super(*args) do |event, name, data|
-          if (event ==  XMLParser::EXTERNAL_ENTITY_REF)
+          if (event ==  XML::Parser::EXTERNAL_ENTITY_REF)
             base, systemId, publicId = data
-            extp = type.new(self, name)
+            extp = self.class.new(self, name)
             extp.parse(readResource(base, systemId)) do |event, name, data|
               yield(event, name, data)
             end
@@ -31,7 +31,7 @@ module XML
 
     def externalEntityRef(context, base, systemId, publicId)
 ##      p ["externalEntityRef", context, base, systemId, publicId]
-      extp = type.new(self, context)
+      extp = self.class.new(self, context)
       extp.parse(readResource(base, systemId))
       extp.done
     end
