@@ -1,7 +1,7 @@
 #! /usr/local/bin/ruby -Ke
 
-require "xmltree"
-include XML::SimpleTree
+require "xml/dom/core"
+include XML::DOM
 
 tree = Document.new(ProcessingInstruction.new("xml",
                                          "version='1.0' encoding='EUC-JP'"),
