@@ -4,8 +4,8 @@
 ## 1998 by yoshidam
 ##
 
-require 'xmltreebuilder'
-require 'xmltreevisitor'
+require 'xml/dom/builder'
+require 'xml/dom/visitor'
 
 class Writer
   def visit_Document(document)
@@ -39,5 +39,5 @@ class Writer
   end
 end
 
-doc = XML::SimpleTreeBuilder.new.parse($<.read)
+doc = XML::DOM::Builder.new.parse($<.read)
 doc.accept(Writer.new)
